@@ -10,7 +10,8 @@ use IO::Socket::INET;
 use PadWalker qw/peek_my peek_our/;
 use Scalar::Util;
 use Encode;
-our $VERSION = "1.6.0";
+use overload;
+our $VERSION = "1.6.1.0";
 
 #sub FLAG_REPORT_GOTO() {0x80;}
 
@@ -513,7 +514,8 @@ sub _get_reference_descriptor
     my $ref = ref $value;
 
     my $size = 0;
-    my $type = $ref;
+    my $type = overload::StrVal( $value );
+
     my $expandable = \0;
     my $is_blessed = $ref && Scalar::Util::blessed( $value ) ? \1 : \0;
     my $ref_depth = 0;
@@ -540,13 +542,13 @@ sub _get_reference_descriptor
     elsif ($reftype eq 'ARRAY')
     {
         $size = scalar @$value;
-        $value = sprintf "ARRAY[%s]", $size;
+        $value = sprintf "size = %s", $size;
         $expandable = $size ? \1 : \0;
     }
     elsif ($reftype eq 'HASH')
     {
         $size = scalar keys %$value;
-        $value = sprintf "HASH{%s}", $size;
+        $value = sprintf "size = %s", $size;
         $expandable = $size ? \1 : \0;
     }
     elsif ($reftype eq 'GLOB')
